@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2011-2021 Canonical
- * Copyright (C) 2021 Colin Ian King
+ * Copyright (C) 2021-2022 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -180,7 +180,7 @@ typedef struct pid_info {
 } pid_info_t;
 
 typedef struct {
-	double		threshold;	/* scaling threashold */
+	double		threshold;	/* scaling threshold */
 	double		scale;		/* scaling value */
 	char 		*suffix;	/* Human Hz scale factor */
 } cpu_freq_scale_t;
@@ -839,7 +839,7 @@ static char *get_pid_cmdline(const pid_t pid)
 	char *ptr;
 	int fd;
 	ssize_t ret;
-	pid_info_t *info;
+	pid_info_t *info = NULL;
 	int h = pid % PID_HASH_SIZE;
 	char path[PATH_MAX];
 	struct stat statbuf;
